# Changelog

## 0.0.1-alpha.1 (2024-12-04)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/TJC-LP/grata-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* go live ([#1](https://github.com/TJC-LP/grata-python/issues/1)) ([efe1e6a](https://github.com/TJC-LP/grata-python/commit/efe1e6ae13df5b973574258a1e8df4cbbd8dc009))
